@@ -96,15 +96,29 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
-AssociateRepositoryRequestRequestTypeDef = TypedDict(
-    "AssociateRepositoryRequestRequestTypeDef",
+_RequiredAssociateRepositoryRequestRequestTypeDef = TypedDict(
+    "_RequiredAssociateRepositoryRequestRequestTypeDef",
     {
         "Repository": "RepositoryTypeDef",
-        "ClientRequestToken": NotRequired[str],
-        "Tags": NotRequired[Mapping[str, str]],
-        "KMSKeyDetails": NotRequired["KMSKeyDetailsTypeDef"],
     },
 )
+_OptionalAssociateRepositoryRequestRequestTypeDef = TypedDict(
+    "_OptionalAssociateRepositoryRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "Tags": Mapping[str, str],
+        "KMSKeyDetails": "KMSKeyDetailsTypeDef",
+    },
+    total=False,
+)
+
+
+class AssociateRepositoryRequestRequestTypeDef(
+    _RequiredAssociateRepositoryRequestRequestTypeDef,
+    _OptionalAssociateRepositoryRequestRequestTypeDef,
+):
+    pass
+
 
 AssociateRepositoryResponseTypeDef = TypedDict(
     "AssociateRepositoryResponseTypeDef",
@@ -123,13 +137,24 @@ BranchDiffSourceCodeTypeTypeDef = TypedDict(
     },
 )
 
-CodeArtifactsTypeDef = TypedDict(
-    "CodeArtifactsTypeDef",
+_RequiredCodeArtifactsTypeDef = TypedDict(
+    "_RequiredCodeArtifactsTypeDef",
     {
         "SourceCodeArtifactsObjectKey": str,
-        "BuildArtifactsObjectKey": NotRequired[str],
     },
 )
+_OptionalCodeArtifactsTypeDef = TypedDict(
+    "_OptionalCodeArtifactsTypeDef",
+    {
+        "BuildArtifactsObjectKey": str,
+    },
+    total=False,
+)
+
+
+class CodeArtifactsTypeDef(_RequiredCodeArtifactsTypeDef, _OptionalCodeArtifactsTypeDef):
+    pass
+
 
 CodeCommitRepositoryTypeDef = TypedDict(
     "CodeCommitRepositoryTypeDef",
@@ -141,68 +166,95 @@ CodeCommitRepositoryTypeDef = TypedDict(
 CodeReviewSummaryTypeDef = TypedDict(
     "CodeReviewSummaryTypeDef",
     {
-        "Name": NotRequired[str],
-        "CodeReviewArn": NotRequired[str],
-        "RepositoryName": NotRequired[str],
-        "Owner": NotRequired[str],
-        "ProviderType": NotRequired[ProviderTypeType],
-        "State": NotRequired[JobStateType],
-        "CreatedTimeStamp": NotRequired[datetime],
-        "LastUpdatedTimeStamp": NotRequired[datetime],
-        "Type": NotRequired[TypeType],
-        "PullRequestId": NotRequired[str],
-        "MetricsSummary": NotRequired["MetricsSummaryTypeDef"],
-        "SourceCodeType": NotRequired["SourceCodeTypeTypeDef"],
+        "Name": str,
+        "CodeReviewArn": str,
+        "RepositoryName": str,
+        "Owner": str,
+        "ProviderType": ProviderTypeType,
+        "State": JobStateType,
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
+        "Type": TypeType,
+        "PullRequestId": str,
+        "MetricsSummary": "MetricsSummaryTypeDef",
+        "SourceCodeType": "SourceCodeTypeTypeDef",
     },
+    total=False,
 )
 
 CodeReviewTypeDef = TypedDict(
     "CodeReviewTypeDef",
     {
-        "Name": NotRequired[str],
-        "CodeReviewArn": NotRequired[str],
-        "RepositoryName": NotRequired[str],
-        "Owner": NotRequired[str],
-        "ProviderType": NotRequired[ProviderTypeType],
-        "State": NotRequired[JobStateType],
-        "StateReason": NotRequired[str],
-        "CreatedTimeStamp": NotRequired[datetime],
-        "LastUpdatedTimeStamp": NotRequired[datetime],
-        "Type": NotRequired[TypeType],
-        "PullRequestId": NotRequired[str],
-        "SourceCodeType": NotRequired["SourceCodeTypeTypeDef"],
-        "AssociationArn": NotRequired[str],
-        "Metrics": NotRequired["MetricsTypeDef"],
-        "AnalysisTypes": NotRequired[List[AnalysisTypeType]],
+        "Name": str,
+        "CodeReviewArn": str,
+        "RepositoryName": str,
+        "Owner": str,
+        "ProviderType": ProviderTypeType,
+        "State": JobStateType,
+        "StateReason": str,
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
+        "Type": TypeType,
+        "PullRequestId": str,
+        "SourceCodeType": "SourceCodeTypeTypeDef",
+        "AssociationArn": str,
+        "Metrics": "MetricsTypeDef",
+        "AnalysisTypes": List[AnalysisTypeType],
     },
+    total=False,
 )
 
-CodeReviewTypeTypeDef = TypedDict(
-    "CodeReviewTypeTypeDef",
+_RequiredCodeReviewTypeTypeDef = TypedDict(
+    "_RequiredCodeReviewTypeTypeDef",
     {
         "RepositoryAnalysis": "RepositoryAnalysisTypeDef",
-        "AnalysisTypes": NotRequired[Sequence[AnalysisTypeType]],
     },
 )
+_OptionalCodeReviewTypeTypeDef = TypedDict(
+    "_OptionalCodeReviewTypeTypeDef",
+    {
+        "AnalysisTypes": Sequence[AnalysisTypeType],
+    },
+    total=False,
+)
+
+
+class CodeReviewTypeTypeDef(_RequiredCodeReviewTypeTypeDef, _OptionalCodeReviewTypeTypeDef):
+    pass
+
 
 CommitDiffSourceCodeTypeTypeDef = TypedDict(
     "CommitDiffSourceCodeTypeTypeDef",
     {
-        "SourceCommit": NotRequired[str],
-        "DestinationCommit": NotRequired[str],
-        "MergeBaseCommit": NotRequired[str],
+        "SourceCommit": str,
+        "DestinationCommit": str,
+        "MergeBaseCommit": str,
     },
+    total=False,
 )
 
-CreateCodeReviewRequestRequestTypeDef = TypedDict(
-    "CreateCodeReviewRequestRequestTypeDef",
+_RequiredCreateCodeReviewRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateCodeReviewRequestRequestTypeDef",
     {
         "Name": str,
         "RepositoryAssociationArn": str,
         "Type": "CodeReviewTypeTypeDef",
-        "ClientRequestToken": NotRequired[str],
     },
 )
+_OptionalCreateCodeReviewRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateCodeReviewRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class CreateCodeReviewRequestRequestTypeDef(
+    _RequiredCreateCodeReviewRequestRequestTypeDef, _OptionalCreateCodeReviewRequestRequestTypeDef
+):
+    pass
+
 
 CreateCodeReviewResponseTypeDef = TypedDict(
     "CreateCodeReviewResponseTypeDef",
@@ -212,13 +264,27 @@ CreateCodeReviewResponseTypeDef = TypedDict(
     },
 )
 
-DescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef = TypedDict(
-    "DescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
+_RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef = TypedDict(
+    "_RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
     {
         "CodeReviewArn": str,
-        "WaiterConfig": NotRequired["WaiterConfigTypeDef"],
     },
 )
+_OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef = TypedDict(
+    "_OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
+    {
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef(
+    _RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef,
+    _OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef,
+):
+    pass
+
 
 DescribeCodeReviewRequestRequestTypeDef = TypedDict(
     "DescribeCodeReviewRequestRequestTypeDef",
@@ -235,14 +301,28 @@ DescribeCodeReviewResponseTypeDef = TypedDict(
     },
 )
 
-DescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
-    "DescribeRecommendationFeedbackRequestRequestTypeDef",
+_RequiredDescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeRecommendationFeedbackRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
         "RecommendationId": str,
-        "UserId": NotRequired[str],
     },
 )
+_OptionalDescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeRecommendationFeedbackRequestRequestTypeDef",
+    {
+        "UserId": str,
+    },
+    total=False,
+)
+
+
+class DescribeRecommendationFeedbackRequestRequestTypeDef(
+    _RequiredDescribeRecommendationFeedbackRequestRequestTypeDef,
+    _OptionalDescribeRecommendationFeedbackRequestRequestTypeDef,
+):
+    pass
+
 
 DescribeRecommendationFeedbackResponseTypeDef = TypedDict(
     "DescribeRecommendationFeedbackResponseTypeDef",
@@ -252,13 +332,27 @@ DescribeRecommendationFeedbackResponseTypeDef = TypedDict(
     },
 )
 
-DescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef = TypedDict(
-    "DescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
+_RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef = TypedDict(
+    "_RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
     {
         "AssociationArn": str,
-        "WaiterConfig": NotRequired["WaiterConfigTypeDef"],
     },
 )
+_OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef = TypedDict(
+    "_OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
+    {
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef(
+    _RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef,
+    _OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef,
+):
+    pass
+
 
 DescribeRepositoryAssociationRequestRequestTypeDef = TypedDict(
     "DescribeRepositoryAssociationRequestRequestTypeDef",
@@ -295,30 +389,45 @@ DisassociateRepositoryResponseTypeDef = TypedDict(
 EventInfoTypeDef = TypedDict(
     "EventInfoTypeDef",
     {
-        "Name": NotRequired[str],
-        "State": NotRequired[str],
+        "Name": str,
+        "State": str,
     },
+    total=False,
 )
 
 KMSKeyDetailsTypeDef = TypedDict(
     "KMSKeyDetailsTypeDef",
     {
-        "KMSKeyId": NotRequired[str],
-        "EncryptionOption": NotRequired[EncryptionOptionType],
+        "KMSKeyId": str,
+        "EncryptionOption": EncryptionOptionType,
     },
+    total=False,
 )
 
-ListCodeReviewsRequestRequestTypeDef = TypedDict(
-    "ListCodeReviewsRequestRequestTypeDef",
+_RequiredListCodeReviewsRequestRequestTypeDef = TypedDict(
+    "_RequiredListCodeReviewsRequestRequestTypeDef",
     {
         "Type": TypeType,
-        "ProviderTypes": NotRequired[Sequence[ProviderTypeType]],
-        "States": NotRequired[Sequence[JobStateType]],
-        "RepositoryNames": NotRequired[Sequence[str]],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListCodeReviewsRequestRequestTypeDef = TypedDict(
+    "_OptionalListCodeReviewsRequestRequestTypeDef",
+    {
+        "ProviderTypes": Sequence[ProviderTypeType],
+        "States": Sequence[JobStateType],
+        "RepositoryNames": Sequence[str],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListCodeReviewsRequestRequestTypeDef(
+    _RequiredListCodeReviewsRequestRequestTypeDef, _OptionalListCodeReviewsRequestRequestTypeDef
+):
+    pass
+
 
 ListCodeReviewsResponseTypeDef = TypedDict(
     "ListCodeReviewsResponseTypeDef",
@@ -329,16 +438,30 @@ ListCodeReviewsResponseTypeDef = TypedDict(
     },
 )
 
-ListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
-    "ListRecommendationFeedbackRequestRequestTypeDef",
+_RequiredListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "_RequiredListRecommendationFeedbackRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "UserIds": NotRequired[Sequence[str]],
-        "RecommendationIds": NotRequired[Sequence[str]],
     },
 )
+_OptionalListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "_OptionalListRecommendationFeedbackRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "UserIds": Sequence[str],
+        "RecommendationIds": Sequence[str],
+    },
+    total=False,
+)
+
+
+class ListRecommendationFeedbackRequestRequestTypeDef(
+    _RequiredListRecommendationFeedbackRequestRequestTypeDef,
+    _OptionalListRecommendationFeedbackRequestRequestTypeDef,
+):
+    pass
+
 
 ListRecommendationFeedbackResponseTypeDef = TypedDict(
     "ListRecommendationFeedbackResponseTypeDef",
@@ -349,14 +472,28 @@ ListRecommendationFeedbackResponseTypeDef = TypedDict(
     },
 )
 
-ListRecommendationsRequestRequestTypeDef = TypedDict(
-    "ListRecommendationsRequestRequestTypeDef",
+_RequiredListRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredListRecommendationsRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalListRecommendationsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListRecommendationsRequestRequestTypeDef(
+    _RequiredListRecommendationsRequestRequestTypeDef,
+    _OptionalListRecommendationsRequestRequestTypeDef,
+):
+    pass
+
 
 ListRecommendationsResponseTypeDef = TypedDict(
     "ListRecommendationsResponseTypeDef",
@@ -370,24 +507,26 @@ ListRecommendationsResponseTypeDef = TypedDict(
 ListRepositoryAssociationsRequestListRepositoryAssociationsPaginateTypeDef = TypedDict(
     "ListRepositoryAssociationsRequestListRepositoryAssociationsPaginateTypeDef",
     {
-        "ProviderTypes": NotRequired[Sequence[ProviderTypeType]],
-        "States": NotRequired[Sequence[RepositoryAssociationStateType]],
-        "Names": NotRequired[Sequence[str]],
-        "Owners": NotRequired[Sequence[str]],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "ProviderTypes": Sequence[ProviderTypeType],
+        "States": Sequence[RepositoryAssociationStateType],
+        "Names": Sequence[str],
+        "Owners": Sequence[str],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListRepositoryAssociationsRequestRequestTypeDef = TypedDict(
     "ListRepositoryAssociationsRequestRequestTypeDef",
     {
-        "ProviderTypes": NotRequired[Sequence[ProviderTypeType]],
-        "States": NotRequired[Sequence[RepositoryAssociationStateType]],
-        "Names": NotRequired[Sequence[str]],
-        "Owners": NotRequired[Sequence[str]],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "ProviderTypes": Sequence[ProviderTypeType],
+        "States": Sequence[RepositoryAssociationStateType],
+        "Names": Sequence[str],
+        "Owners": Sequence[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListRepositoryAssociationsResponseTypeDef = TypedDict(
@@ -417,26 +556,29 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 MetricsSummaryTypeDef = TypedDict(
     "MetricsSummaryTypeDef",
     {
-        "MeteredLinesOfCodeCount": NotRequired[int],
-        "FindingsCount": NotRequired[int],
+        "MeteredLinesOfCodeCount": int,
+        "FindingsCount": int,
     },
+    total=False,
 )
 
 MetricsTypeDef = TypedDict(
     "MetricsTypeDef",
     {
-        "MeteredLinesOfCodeCount": NotRequired[int],
-        "FindingsCount": NotRequired[int],
+        "MeteredLinesOfCodeCount": int,
+        "FindingsCount": int,
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PutRecommendationFeedbackRequestRequestTypeDef = TypedDict(
@@ -451,76 +593,82 @@ PutRecommendationFeedbackRequestRequestTypeDef = TypedDict(
 RecommendationFeedbackSummaryTypeDef = TypedDict(
     "RecommendationFeedbackSummaryTypeDef",
     {
-        "RecommendationId": NotRequired[str],
-        "Reactions": NotRequired[List[ReactionType]],
-        "UserId": NotRequired[str],
+        "RecommendationId": str,
+        "Reactions": List[ReactionType],
+        "UserId": str,
     },
+    total=False,
 )
 
 RecommendationFeedbackTypeDef = TypedDict(
     "RecommendationFeedbackTypeDef",
     {
-        "CodeReviewArn": NotRequired[str],
-        "RecommendationId": NotRequired[str],
-        "Reactions": NotRequired[List[ReactionType]],
-        "UserId": NotRequired[str],
-        "CreatedTimeStamp": NotRequired[datetime],
-        "LastUpdatedTimeStamp": NotRequired[datetime],
+        "CodeReviewArn": str,
+        "RecommendationId": str,
+        "Reactions": List[ReactionType],
+        "UserId": str,
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
     },
+    total=False,
 )
 
 RecommendationSummaryTypeDef = TypedDict(
     "RecommendationSummaryTypeDef",
     {
-        "FilePath": NotRequired[str],
-        "RecommendationId": NotRequired[str],
-        "StartLine": NotRequired[int],
-        "EndLine": NotRequired[int],
-        "Description": NotRequired[str],
-        "RecommendationCategory": NotRequired[RecommendationCategoryType],
-        "RuleMetadata": NotRequired["RuleMetadataTypeDef"],
-        "Severity": NotRequired[SeverityType],
+        "FilePath": str,
+        "RecommendationId": str,
+        "StartLine": int,
+        "EndLine": int,
+        "Description": str,
+        "RecommendationCategory": RecommendationCategoryType,
+        "RuleMetadata": "RuleMetadataTypeDef",
+        "Severity": SeverityType,
     },
+    total=False,
 )
 
 RepositoryAnalysisTypeDef = TypedDict(
     "RepositoryAnalysisTypeDef",
     {
-        "RepositoryHead": NotRequired["RepositoryHeadSourceCodeTypeTypeDef"],
-        "SourceCodeType": NotRequired["SourceCodeTypeTypeDef"],
+        "RepositoryHead": "RepositoryHeadSourceCodeTypeTypeDef",
+        "SourceCodeType": "SourceCodeTypeTypeDef",
     },
+    total=False,
 )
 
 RepositoryAssociationSummaryTypeDef = TypedDict(
     "RepositoryAssociationSummaryTypeDef",
     {
-        "AssociationArn": NotRequired[str],
-        "ConnectionArn": NotRequired[str],
-        "LastUpdatedTimeStamp": NotRequired[datetime],
-        "AssociationId": NotRequired[str],
-        "Name": NotRequired[str],
-        "Owner": NotRequired[str],
-        "ProviderType": NotRequired[ProviderTypeType],
-        "State": NotRequired[RepositoryAssociationStateType],
+        "AssociationArn": str,
+        "ConnectionArn": str,
+        "LastUpdatedTimeStamp": datetime,
+        "AssociationId": str,
+        "Name": str,
+        "Owner": str,
+        "ProviderType": ProviderTypeType,
+        "State": RepositoryAssociationStateType,
     },
+    total=False,
 )
 
 RepositoryAssociationTypeDef = TypedDict(
     "RepositoryAssociationTypeDef",
     {
-        "AssociationId": NotRequired[str],
-        "AssociationArn": NotRequired[str],
-        "ConnectionArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Owner": NotRequired[str],
-        "ProviderType": NotRequired[ProviderTypeType],
-        "State": NotRequired[RepositoryAssociationStateType],
-        "StateReason": NotRequired[str],
-        "LastUpdatedTimeStamp": NotRequired[datetime],
-        "CreatedTimeStamp": NotRequired[datetime],
-        "KMSKeyDetails": NotRequired["KMSKeyDetailsTypeDef"],
-        "S3RepositoryDetails": NotRequired["S3RepositoryDetailsTypeDef"],
+        "AssociationId": str,
+        "AssociationArn": str,
+        "ConnectionArn": str,
+        "Name": str,
+        "Owner": str,
+        "ProviderType": ProviderTypeType,
+        "State": RepositoryAssociationStateType,
+        "StateReason": str,
+        "LastUpdatedTimeStamp": datetime,
+        "CreatedTimeStamp": datetime,
+        "KMSKeyDetails": "KMSKeyDetailsTypeDef",
+        "S3RepositoryDetails": "S3RepositoryDetailsTypeDef",
     },
+    total=False,
 )
 
 RepositoryHeadSourceCodeTypeTypeDef = TypedDict(
@@ -533,21 +681,23 @@ RepositoryHeadSourceCodeTypeTypeDef = TypedDict(
 RepositoryTypeDef = TypedDict(
     "RepositoryTypeDef",
     {
-        "CodeCommit": NotRequired["CodeCommitRepositoryTypeDef"],
-        "Bitbucket": NotRequired["ThirdPartySourceRepositoryTypeDef"],
-        "GitHubEnterpriseServer": NotRequired["ThirdPartySourceRepositoryTypeDef"],
-        "S3Bucket": NotRequired["S3RepositoryTypeDef"],
+        "CodeCommit": "CodeCommitRepositoryTypeDef",
+        "Bitbucket": "ThirdPartySourceRepositoryTypeDef",
+        "GitHubEnterpriseServer": "ThirdPartySourceRepositoryTypeDef",
+        "S3Bucket": "S3RepositoryTypeDef",
     },
+    total=False,
 )
 
 RequestMetadataTypeDef = TypedDict(
     "RequestMetadataTypeDef",
     {
-        "RequestId": NotRequired[str],
-        "Requester": NotRequired[str],
-        "EventInfo": NotRequired["EventInfoTypeDef"],
-        "VendorName": NotRequired[VendorNameType],
+        "RequestId": str,
+        "Requester": str,
+        "EventInfo": "EventInfoTypeDef",
+        "VendorName": VendorNameType,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -564,28 +714,43 @@ ResponseMetadataTypeDef = TypedDict(
 RuleMetadataTypeDef = TypedDict(
     "RuleMetadataTypeDef",
     {
-        "RuleId": NotRequired[str],
-        "RuleName": NotRequired[str],
-        "ShortDescription": NotRequired[str],
-        "LongDescription": NotRequired[str],
-        "RuleTags": NotRequired[List[str]],
+        "RuleId": str,
+        "RuleName": str,
+        "ShortDescription": str,
+        "LongDescription": str,
+        "RuleTags": List[str],
     },
+    total=False,
 )
 
-S3BucketRepositoryTypeDef = TypedDict(
-    "S3BucketRepositoryTypeDef",
+_RequiredS3BucketRepositoryTypeDef = TypedDict(
+    "_RequiredS3BucketRepositoryTypeDef",
     {
         "Name": str,
-        "Details": NotRequired["S3RepositoryDetailsTypeDef"],
     },
 )
+_OptionalS3BucketRepositoryTypeDef = TypedDict(
+    "_OptionalS3BucketRepositoryTypeDef",
+    {
+        "Details": "S3RepositoryDetailsTypeDef",
+    },
+    total=False,
+)
+
+
+class S3BucketRepositoryTypeDef(
+    _RequiredS3BucketRepositoryTypeDef, _OptionalS3BucketRepositoryTypeDef
+):
+    pass
+
 
 S3RepositoryDetailsTypeDef = TypedDict(
     "S3RepositoryDetailsTypeDef",
     {
-        "BucketName": NotRequired[str],
-        "CodeArtifacts": NotRequired["CodeArtifactsTypeDef"],
+        "BucketName": str,
+        "CodeArtifacts": "CodeArtifactsTypeDef",
     },
+    total=False,
 )
 
 S3RepositoryTypeDef = TypedDict(
@@ -599,12 +764,13 @@ S3RepositoryTypeDef = TypedDict(
 SourceCodeTypeTypeDef = TypedDict(
     "SourceCodeTypeTypeDef",
     {
-        "CommitDiff": NotRequired["CommitDiffSourceCodeTypeTypeDef"],
-        "RepositoryHead": NotRequired["RepositoryHeadSourceCodeTypeTypeDef"],
-        "BranchDiff": NotRequired["BranchDiffSourceCodeTypeTypeDef"],
-        "S3BucketRepository": NotRequired["S3BucketRepositoryTypeDef"],
-        "RequestMetadata": NotRequired["RequestMetadataTypeDef"],
+        "CommitDiff": "CommitDiffSourceCodeTypeTypeDef",
+        "RepositoryHead": "RepositoryHeadSourceCodeTypeTypeDef",
+        "BranchDiff": "BranchDiffSourceCodeTypeTypeDef",
+        "S3BucketRepository": "S3BucketRepositoryTypeDef",
+        "RequestMetadata": "RequestMetadataTypeDef",
     },
+    total=False,
 )
 
 TagResourceRequestRequestTypeDef = TypedDict(
@@ -635,7 +801,8 @@ UntagResourceRequestRequestTypeDef = TypedDict(
 WaiterConfigTypeDef = TypedDict(
     "WaiterConfigTypeDef",
     {
-        "Delay": NotRequired[int],
-        "MaxAttempts": NotRequired[int],
+        "Delay": int,
+        "MaxAttempts": int,
     },
+    total=False,
 )
